#ifndef LIBKYDEVICESEC_WIFI_H
#define LIBKYDEVICESEC_WIFI_H

#ifdef __cplusplus
extern "C" {
#endif

typedef enum _kdk_wifi_status {
    KDK_WIFI_DISABLE = 0,
    KDK_WIFI_ENABLE,
} kdk_wifi_status;

typedef enum _kdk_wifi_mode {
    KDK_WIFI_MODE_NORMAL = 0,
    KDK_WIFI_MODE_BLACKLIST,
    KDK_WIFI_MODE_WHITELIST,
} kdk_wifi_mode;

/**
 * wifi管控
 */

/**
 * @brief 设置wifi管控状态
 * @param status [in] wifi管控状态，参见kdk_wifi_status
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_set_wireless_wifi_status(int status);

/**
 * @brief 获取wifi管控状态
 * @return int 返回0表示禁用，返回1表示启用，返回-1表示失败
 */
extern int kdk_device_get_wireless_wifi_status();

/**
 * @brief 设置wifi管控黑白名单模式
 * @param mode[in]: wifi管控模式，参见kdk_wifi_mode
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_set_wireless_wifi_bwm(int mode);

/**
 * @brief 获取wifi管控黑白名单模式
 * @return 返回0表示普通模式，返回1表示黑名单模式，返回2表示白名单模式，返回-1表示失败
 */
extern int kdk_device_get_wireless_wifi_bwm();

/**
 * @brief 设置wifi管控黑名单
 * @param bssid[in]: 无线网络的bssid
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_set_wireless_wifi_blacklist(const char *bssid);

/**
 * @brief 删除wifi管控黑名单节点
 * @param bssid[in]: 无线网络的bssid
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_del_wireless_wifi_blacklist(const char *bssid);

/**
 * @brief 清空wifi管控黑名单
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_clear_wireless_wifi_blacklist();

/**
 * @brief 获取wifi管控黑名单
 * @param len[out]:黑名单长度
 * @return 黑名单列表
 */
extern char** kdk_device_get_wireless_wifi_blacklist(int *len);

/**
 * @brief 设置wifi管控白名单
 * @param bssid[in]: 无线网络的bssid
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_set_wireless_wifi_whitelist(const char *bssid);

/**
 * @brief 删除wifi管控白名单节点
 * @param bssid[in]: 无线网络的bssid
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_del_wireless_wifi_whitelist(const char *bssid);

/**
 * @brief 清空wifi管控白名单
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_clear_wireless_wifi_whitelist();

/**
 * @brief 获取wifi管控白名单
 * @param len[out]:白名单长度
 * @return 白名单列表
 */
extern char** kdk_device_get_wireless_wifi_whitelist(int *len);
#ifdef __cplusplus
}
#endif

#endif
